==> spatstat_1.31-3.tar.gz: spatstat/man/rMaternI.Rd <==
\name{rMaternI}
\alias{rMaternI}
\title{Simulate Matern Model I}
\description{
  Generate a random point pattern, a simulated realisation of the
  \ifelse{latex}{\out{Mat\'ern}}{Matern} Model I inhibition process model.
}
\usage{
 rMaternI(kappa, r, win = owin(c(0,1),c(0,1)), stationary=TRUE)
}
\arguments{
  \item{kappa}{
    Intensity of the Poisson process of proposal points.
    A single positive number.
  }
  \item{r}{
    Inhibition distance.
  }
  \item{win}{
    Window in which to simulate the pattern.
    An object of class \code{"owin"}
    or something acceptable to \code{\link{as.owin}}.
  }
  \item{stationary}{
    Logical. Whether to start with a stationary process of proposal points
    (\code{stationary=TRUE}) or to generate the
    proposal points only inside the window (\code{stationary=FALSE}).
  }
}
\value{
  The simulated point pattern (an object of class \code{"ppp"}).
}
\details{
  This algorithm generates a realisation of \ifelse{latex}{\out{Mat\'ern}}{Matern}'s Model I
  inhibition process inside the window \code{win}.

  The process is constructed by first
  generating a uniform Poisson point process of ``proposal'' points 
  with intensity \code{kappa}. If \code{stationary = TRUE} (the
  default), the proposal points are generated in a window larger than
  \code{win} that effectively means the proposals are stationary.
  If \code{stationary=FALSE} then the proposal points are
  only generated inside the window \code{win}.

  A proposal point is then deleted if it lies within \code{r} units' distance
  of another proposal point. Otherwise it is retained.
  
  The retained points constitute \ifelse{latex}{\out{Mat\'ern}}{Matern}'s Model I.
}
\seealso{
\code{\link{rpoispp}},
\code{\link{rMatClust}}
}
\examples{
 X <- rMaternI(20, 0.05)
 Y <- rMaternI(20, 0.05, stationary=FALSE)
}
\author{Adrian Baddeley
  \email{Adrian.Baddeley@csiro.au}
  \url{http://www.maths.uwa.edu.au/~adrian/},
  Ute Hahn,
  and Rolf Turner
  \email{r.turner@auckland.ac.nz}
}
\keyword{spatial}
\keyword{datagen}

==> spatstat_1.39-1.tar.gz: spatstat/man/rMaternI.Rd <==
\name{rMaternI}
\alias{rMaternI}
\title{Simulate Matern Model I}
\description{
  Generate a random point pattern, a simulated realisation of the
  \ifelse{latex}{\out{Mat\'ern}}{Matern} Model I inhibition process model.
}
\usage{
 rMaternI(kappa, r, win = owin(c(0,1),c(0,1)), stationary=TRUE)
}
\arguments{
  \item{kappa}{
    Intensity of the Poisson process of proposal points.
    A single positive number.
  }
  \item{r}{
    Inhibition distance.
  }
  \item{win}{
    Window in which to simulate the pattern.
    An object of class \code{"owin"}
    or something acceptable to \code{\link{as.owin}}.
  }
  \item{stationary}{
    Logical. Whether to start with a stationary process of proposal points
    (\code{stationary=TRUE}) or to generate the
    proposal points only inside the window (\code{stationary=FALSE}).
  }
}
\value{
  The simulated point pattern (an object of class \code{"ppp"}).
}
\details{
  This algorithm generates a realisation of \ifelse{latex}{\out{Mat\'ern}}{Matern}'s Model I
  inhibition process inside the window \code{win}.

  The process is constructed by first
  generating a uniform Poisson point process of ``proposal'' points 
  with intensity \code{kappa}. If \code{stationary = TRUE} (the
  default), the proposal points are generated in a window larger than
  \code{win} that effectively means the proposals are stationary.
  If \code{stationary=FALSE} then the proposal points are
  only generated inside the window \code{win}.

  A proposal point is then deleted if it lies within \code{r} units' distance
  of another proposal point. Otherwise it is retained.
  
  The retained points constitute \ifelse{latex}{\out{Mat\'ern}}{Matern}'s Model I.
}
\seealso{
\code{\link{rpoispp}},
\code{\link{rMatClust}}
}
\examples{
 X <- rMaternI(20, 0.05)
 Y <- rMaternI(20, 0.05, stationary=FALSE)
}
\author{Adrian Baddeley
  \email{Adrian.Baddeley@uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/},
  Ute Hahn,
  and Rolf Turner
  \email{r.turner@auckland.ac.nz}
}
\keyword{spatial}
\keyword{datagen}
